==> haskell-libmpd-0.10.0.1-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libmpd.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 libmpd
version:              0.10.0.1
visibility:           public
id:                   libmpd-0.10.0.1-IIYcaBftvBZIdyOdlVyNxF
key:                  libmpd-0.10.0.1-IIYcaBftvBZIdyOdlVyNxF
license:              MIT
copyright:
    Ben Sinclair 2005-2009, Joachim Fasting 2007-2015,
    Daniel Schoepe 2009, Andrzej Rybczak 2010,
    Simon Hengel 2011-2014, Niklas Haas 2012,
    Matvey Aksenov 2014, Wieland Hoffmann 2014,
    Tim Heap 2014, Tobias Brandt 2014

maintainer:           Joachim Fasting <joachifm@fastmail.fm>
author:               Ben Sinclair
stability:            beta
homepage:             http://github.com/vimus/libmpd-haskell#readme
synopsis:             An MPD client library.
description:          A client library for MPD, the Music Player Daemon.
category:             Network, Sound
abi:                  a83e8a8c75afabb3896e98f5fd17e191
exposed:              True
exposed-modules:
    Network.MPD Network.MPD.Applicative
    Network.MPD.Applicative.ClientToClient
    Network.MPD.Applicative.Connection
    Network.MPD.Applicative.CurrentPlaylist
    Network.MPD.Applicative.Database Network.MPD.Applicative.Mount
    Network.MPD.Applicative.Output
    Network.MPD.Applicative.PlaybackControl
    Network.MPD.Applicative.PlaybackOptions
    Network.MPD.Applicative.Reflection Network.MPD.Applicative.Status
    Network.MPD.Applicative.Stickers
    Network.MPD.Applicative.StoredPlaylists
    Network.MPD.Commands.Extensions Network.MPD.Core

hidden-modules:
    Network.MPD.Core.Class Network.MPD.Core.Error Network.MPD.Commands
    Network.MPD.Commands.Arg Network.MPD.Commands.Parse
    Network.MPD.Commands.Query Network.MPD.Commands.Types
    Network.MPD.Commands.ClientToClient Network.MPD.Commands.Status
    Network.MPD.Commands.PlaybackOptions
    Network.MPD.Commands.PlaybackControl
    Network.MPD.Commands.CurrentPlaylist
    Network.MPD.Commands.StoredPlaylists Network.MPD.Commands.Database
    Network.MPD.Commands.Stickers Network.MPD.Commands.Connection
    Network.MPD.Commands.Output Network.MPD.Commands.Reflection
    Network.MPD.Commands.Mount Network.MPD.Applicative.Util
    Network.MPD.Applicative.Internal Network.MPD.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/libmpd-0.10.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/libmpd-0.10.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/libmpd-0.10.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-libmpd
hs-libraries:         HSlibmpd-0.10.0.1-IIYcaBftvBZIdyOdlVyNxF
depends:
    attoparsec-0.14.4-21g0xvIiXNtBpdLdrKPYdv base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc filepath-1.4.2.2
    mtl-2.2.2 network-3.1.4.0-4LxzNodBXIzL8bUGme1k8m
    safe-exceptions-0.1.7.4-2aYxNbFpmMwKpdUZnREf2B text-2.0.2
    time-1.12.2 utf8-string-1.0.2-7x3IoasPx5wHP6oJo1JvJP

haddock-interfaces:   /usr/share/doc/haskell-libmpd/html/libmpd.haddock
haddock-html:         /usr/share/doc/haskell-libmpd/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libmpd-0.10.0.1-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libmpd.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 libmpd
version:              0.10.0.1
visibility:           public
id:                   libmpd-0.10.0.1-JZVj8f8QnCaHykuKOIOALq
key:                  libmpd-0.10.0.1-JZVj8f8QnCaHykuKOIOALq
license:              MIT
copyright:
    Ben Sinclair 2005-2009, Joachim Fasting 2007-2015,
    Daniel Schoepe 2009, Andrzej Rybczak 2010,
    Simon Hengel 2011-2014, Niklas Haas 2012,
    Matvey Aksenov 2014, Wieland Hoffmann 2014,
    Tim Heap 2014, Tobias Brandt 2014

maintainer:           Joachim Fasting <joachifm@fastmail.fm>
author:               Ben Sinclair
stability:            beta
homepage:             http://github.com/vimus/libmpd-haskell#readme
synopsis:             An MPD client library.
description:          A client library for MPD, the Music Player Daemon.
category:             Network, Sound
abi:                  7d3adc32b55bbc3735f250616031aa5f
exposed:              True
exposed-modules:
    Network.MPD Network.MPD.Applicative
    Network.MPD.Applicative.ClientToClient
    Network.MPD.Applicative.Connection
    Network.MPD.Applicative.CurrentPlaylist
    Network.MPD.Applicative.Database Network.MPD.Applicative.Mount
    Network.MPD.Applicative.Output
    Network.MPD.Applicative.PlaybackControl
    Network.MPD.Applicative.PlaybackOptions
    Network.MPD.Applicative.Reflection Network.MPD.Applicative.Status
    Network.MPD.Applicative.Stickers
    Network.MPD.Applicative.StoredPlaylists
    Network.MPD.Commands.Extensions Network.MPD.Core

hidden-modules:
    Network.MPD.Core.Class Network.MPD.Core.Error Network.MPD.Commands
    Network.MPD.Commands.Arg Network.MPD.Commands.Parse
    Network.MPD.Commands.Query Network.MPD.Commands.Types
    Network.MPD.Commands.ClientToClient Network.MPD.Commands.Status
    Network.MPD.Commands.PlaybackOptions
    Network.MPD.Commands.PlaybackControl
    Network.MPD.Commands.CurrentPlaylist
    Network.MPD.Commands.StoredPlaylists Network.MPD.Commands.Database
    Network.MPD.Commands.Stickers Network.MPD.Commands.Connection
    Network.MPD.Commands.Output Network.MPD.Commands.Reflection
    Network.MPD.Commands.Mount Network.MPD.Applicative.Util
    Network.MPD.Applicative.Internal Network.MPD.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/libmpd-0.10.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/libmpd-0.10.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/libmpd-0.10.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-libmpd
hs-libraries:         HSlibmpd-0.10.0.1-JZVj8f8QnCaHykuKOIOALq
depends:
    attoparsec-0.14.4-8RYxJQa7MEjKmC3I11Us4k base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc filepath-1.4.2.2
    mtl-2.2.2 network-3.1.4.0-7d91dIi13MzEkgRQe6YDcO
    safe-exceptions-0.1.7.4-ES7S1HwS0lOI4lBBxEPT7M text-2.0.2
    time-1.12.2 utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:   /usr/share/doc/haskell-libmpd/html/libmpd.haddock
haddock-html:         /usr/share/doc/haskell-libmpd/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
